@@ -25,8 +25,9 @@
 # ***** END LICENSE BLOCK *****
 
 __author__  = "Hayaki Saito (user@zuse.jp)"
-__version__ = "0.2.3"
+__version__ = "0.2.6"
 __license__ = "MIT"
+signature   = 'febb6c52a3e1d52fe530f887fbdd975f'
 
 import sys
 import os
@@ -1354,26 +1355,27 @@ def _test():
 
 ''' main '''
 if __name__ == '__main__':
-    _test()
+
+    import inspect
+    import hashlib
+    import sys
+    
+    thismodule = sys.modules[__name__]
+    md5 = hashlib.md5()
+    specs = []
+    for name, member in inspect.getmembers(thismodule):
+        if inspect.isclass(member):
+            if name[0] != "_":
+                classname = name
+                for name, member in inspect.getmembers(member):
+                    if inspect.ismethod(member):
+                        if name.startswith("__") or name[0] != "_":
+                            argspec = inspect.getargspec(member)
+                            args, varargs, keywords, defaultvalue = argspec
+                            specstr = "%s.%s.%s" % (classname, name, args)
+                            specs.append(specstr)
+    specs.sort()
+    md5.update("".join(specs))
+    sys.stdout.write(md5.hexdigest())
 
 
-import inspect
-import hashlib
-
-thismodule = sys.modules[__name__]
-md5 = hashlib.md5()
-specs = []
-for name, member in inspect.getmembers(thismodule):
-    if inspect.isclass(member):
-        if name[0] != "_":
-            classname = name
-            for name, member in inspect.getmembers(member):
-                if inspect.ismethod(member):
-                    if name.startswith("__") or name[0] != "_":
-                        argspec = inspect.getargspec(member)
-                        args, varargs, keywords, defaultvalue = argspec
-                        specstr = "%s.%s.%s" % (classname, name, args)
-                        specs.append(specstr)
-specs.sort()
-signature = md5.update("".join(specs))
-
